InProgressSignatures

Trait InProgressSignatures 

pub trait InProgressSignatures: Debug {
    type SpendAuth: Debug;
}
Marker trait representing bundle signatures in the process of being created.

Required Associated Types

type SpendAuth: Debug

The authorization type of an Orchard action in the process of being authorized.

Implementors