pub struct Flags { /* private fields */ }Expand description
Orchard-specific flags.
Implementations
Sourceimpl Flags
impl Flags
Sourcepub const SPENDS_DISABLED: Flags
pub const SPENDS_DISABLED: Flags
The flag set with spends disabled.
Sourcepub const OUTPUTS_DISABLED: Flags
pub const OUTPUTS_DISABLED: Flags
The flag set with outputs disabled.
Sourcepub fn spends_enabled(&self) -> bool
pub fn spends_enabled(&self) -> bool
Sourcepub fn outputs_enabled(&self) -> bool
pub fn outputs_enabled(&self) -> bool
Sourcepub fn to_byte(&self) -> u8
pub fn to_byte(&self) -> u8
Serialize flags to a byte as defined in Zcash Protocol Spec  7.1: Transaction Encoding And Consensus.
Sourcepub fn from_byte(value: u8) -> Option<Self>
pub fn from_byte(value: u8) -> Option<Self>
Parses flags from a single byte as defined in Zcash Protocol Spec  7.1: Transaction Encoding And Consensus.
Returns None if unexpected bits are set in the flag byte.