pub struct SpendValidatingKey(/* private fields */);Expand description
A key used to validate spend authorization signatures.
Defined in Zcash Protocol Spec  4.2.3: Orchard Key Components. Note that this is $\mathsf{ak}^\mathbb{P}$, which by construction is equivalent to $\mathsf{ak}$ but stored here as a RedPallas verification key.
Implementations
Sourceimpl SpendValidatingKey
impl SpendValidatingKey
Sourcepub fn randomize(&self, randomizer: &Scalar) -> VerificationKey<SpendAuth>
pub fn randomize(&self, randomizer: &Scalar) -> VerificationKey<SpendAuth>
Randomizes this spend validating key with the given randomizer.
Sourcepub fn to_bytes(&self) -> [u8; 32]
pub fn to_bytes(&self) -> [u8; 32]
Converts this spend validating key to its serialized form, I2LEOSP_256(ak).
Sourcepub fn from_bytes(bytes: &[u8]) -> Option<Self>
pub fn from_bytes(bytes: &[u8]) -> Option<Self>
Attempts to parse a byte slice as a spend validating key, I2LEOSP_256(ak).
Returns None if the given slice does not contain a valid spend validating key.