pub struct Note { /* private fields */ }Expand description
A discrete amount of funds received by an address.
Implementations
Sourceimpl Note
impl Note
Sourcepub fn from_parts(
recipient: Address,
value: NoteValue,
rho: Rho,
rseed: RandomSeed,
) -> CtOption<Self>
pub fn from_parts( recipient: Address, value: NoteValue, rho: Rho, rseed: RandomSeed, ) -> CtOption<Self>
Creates a Note from its component parts.
Returns None if a valid NoteCommitment cannot be derived from the note.
Caveats
This low-level constructor enforces that the provided arguments produce an
internally valid Note. However, it allows notes to be constructed in a way that
violates required security checks for note decryption, as specified in
Section 4.19 of the Zcash Protocol Specification. Users of this constructor
should only call it with note components that have been fully validated by
decrypting a received note according to Section 4.19.
Sourcepub fn new(
recipient: Address,
value: NoteValue,
rho: Rho,
rng: impl RngCore,
) -> Self
pub fn new( recipient: Address, value: NoteValue, rho: Rho, rng: impl RngCore, ) -> Self
Generates a new note.
Defined in Zcash Protocol Spec  4.7.3: Sending Notes (Orchard).
Sourcepub fn dummy(
rng: &mut impl RngCore,
rho: Option<Rho>,
) -> (SpendingKey, FullViewingKey, Self)
pub fn dummy( rng: &mut impl RngCore, rho: Option<Rho>, ) -> (SpendingKey, FullViewingKey, Self)
Generates a dummy spent note.
Defined in Zcash Protocol Spec  4.8.3: Dummy Notes (Orchard).
Sourcepub fn rseed(&self) -> &RandomSeed
pub fn rseed(&self) -> &RandomSeed
Returns the rseed value of this note.
Sourcepub fn commitment(&self) -> NoteCommitment
pub fn commitment(&self) -> NoteCommitment
Derives the commitment to this note.
Defined in Zcash Protocol Spec  3.2: Notes.
Sourcepub fn nullifier(&self, fvk: &FullViewingKey) -> Nullifier
pub fn nullifier(&self, fvk: &FullViewingKey) -> Nullifier
Derives the nullifier for this note.