pub struct RandomSeed(/* private fields */);Expand description
The ZIP 212 seed randomness for a note.
Implementations
Sourceimpl RandomSeed
impl RandomSeed
Sourcepub fn from_bytes(rseed: [u8; 32], rho: &Rho) -> CtOption<Self>
pub fn from_bytes(rseed: [u8; 32], rho: &Rho) -> CtOption<Self>
Reads a note’s random seed from bytes, given the note’s rho value.
Returns None if the rho value is not for the same note as the seed.
Sourcepub fn psi(&self, rho: &Rho) -> Base
pub fn psi(&self, rho: &Rho) -> Base
Defined in Zcash Protocol Spec  4.7.3: Sending Notes (Orchard).
Derives the psi value for this random seed and rho.
Sourcepub fn rcm(&self, rho: &Rho) -> NoteCommitTrapdoor
pub fn rcm(&self, rho: &Rho) -> NoteCommitTrapdoor
Defined in Zcash Protocol Spec  4.7.3: Sending Notes (Orchard).
Derives the note commitment trapdoor for this random seed and rho.