pub struct OrchardDomain { /* private fields */ }Expand description
Orchard-specific note encryption logic.
Implementations
Sourceimpl OrchardDomain
impl OrchardDomain
Sourcepub fn for_action<T>(act: &Action<T>) -> Self
pub fn for_action<T>(act: &Action<T>) -> Self
Constructs a domain that can be used to trial-decrypt this action’s output note.
Sourcepub fn for_pczt_action(act: &Action) -> Self
pub fn for_pczt_action(act: &Action) -> Self
Constructs a domain that can be used to trial-decrypt a PCZT action’s output note.
Sourcepub fn for_compact_action(act: &CompactAction) -> Self
pub fn for_compact_action(act: &CompactAction) -> Self
Constructs a domain that can be used to trial-decrypt this action’s output note.