pub struct Action<A> { /* private fields */ }Expand description
An action applied to the global ledger.
This both creates a note (adding a commitment to the global ledger), and consumes some note created prior to this action (adding a nullifier to the global ledger).
Implementations
Sourceimpl<T> Action<T>
impl<T> Action<T>
Sourcepub fn from_parts(
nf: Nullifier,
rk: VerificationKey<SpendAuth>,
cmx: ExtractedNoteCommitment,
encrypted_note: TransmittedNoteCiphertext,
cv_net: ValueCommitment,
authorization: T,
) -> Self
pub fn from_parts( nf: Nullifier, rk: VerificationKey<SpendAuth>, cmx: ExtractedNoteCommitment, encrypted_note: TransmittedNoteCiphertext, cv_net: ValueCommitment, authorization: T, ) -> Self
Constructs an Action from its constituent parts.
Sourcepub fn rk(&self) -> &VerificationKey<SpendAuth>
pub fn rk(&self) -> &VerificationKey<SpendAuth>
Returns the randomized verification key for the note being spent.
Sourcepub fn cmx(&self) -> &ExtractedNoteCommitment
pub fn cmx(&self) -> &ExtractedNoteCommitment
Returns the commitment to the new note being created.
Sourcepub fn encrypted_note(&self) -> &TransmittedNoteCiphertext
pub fn encrypted_note(&self) -> &TransmittedNoteCiphertext
Returns the encrypted note ciphertext.
Sourcepub fn rho(&self) -> Rho
pub fn rho(&self) -> Rho
Obtains the Rho value that was used to construct the new note being created.
Sourcepub fn cv_net(&self) -> &ValueCommitment
pub fn cv_net(&self) -> &ValueCommitment
Returns the commitment to the net value created or consumed by this action.
Returns the authorization for this action.