pub struct Proof(/* private fields */);Expand description
A proof of the validity of an Orchard Bundle.
Implementations
Sourceimpl Proof
impl Proof
Sourcepub fn create(
pk: &ProvingKey,
circuits: &[Circuit],
instances: &[Instance],
rng: impl RngCore,
) -> Result<Self, Error>
Available on crate feature circuit only.
pub fn create( pk: &ProvingKey, circuits: &[Circuit], instances: &[Instance], rng: impl RngCore, ) -> Result<Self, Error>
circuit only.Creates a proof for the given circuits and instances.
Sourcepub fn verify(
&self,
vk: &VerifyingKey,
instances: &[Instance],
) -> Result<(), Error>
Available on crate feature circuit only.
pub fn verify( &self, vk: &VerifyingKey, instances: &[Instance], ) -> Result<(), Error>
circuit only.Verifies this proof with the given instances.
Sourcepub fn add_to_batch(
&self,
batch: &mut BatchVerifier<Affine>,
instances: Vec<Instance>,
)
Available on crate feature circuit only.
pub fn add_to_batch( &self, batch: &mut BatchVerifier<Affine>, instances: Vec<Instance>, )
circuit only.Adds this proof to the given batch for verification with the given instances.
Use this API if you want more control over how proof batches are processed. If you
just want to batch-validate Orchard bundles, use bundle::BatchValidator.