pub struct Bundle<T: Authorization, V> { /* private fields */ }Expand description
A bundle of actions to be applied to the ledger.
Implementations
Sourceimpl<S: InProgressSignatures, V> Bundle<InProgress<Unproven, S>, V>
impl<S: InProgressSignatures, V> Bundle<InProgress<Unproven, S>, V>
Sourcepub fn create_proof(
self,
pk: &ProvingKey,
rng: impl RngCore,
) -> Result<Bundle<InProgress<Proof, S>, V>, BuildError>
Available on crate feature circuit only.
pub fn create_proof( self, pk: &ProvingKey, rng: impl RngCore, ) -> Result<Bundle<InProgress<Proof, S>, V>, BuildError>
circuit only.Creates the proof for this bundle.
Sourcepub fn prepare<R: RngCore + CryptoRng>(
self,
rng: R,
sighash: [u8; 32],
) -> Bundle<InProgress<P, PartiallyAuthorized>, V>
pub fn prepare<R: RngCore + CryptoRng>( self, rng: R, sighash: [u8; 32], ) -> Bundle<InProgress<P, PartiallyAuthorized>, V>
Loads the sighash into this bundle, preparing it for signing.
This API ensures that all signatures are created over the same sighash.
Sourcepub fn apply_signatures<R: RngCore + CryptoRng>(
self,
rng: R,
sighash: [u8; 32],
signing_keys: &[SpendAuthorizingKey],
) -> Result<Bundle<Authorized, V>, BuildError>
pub fn apply_signatures<R: RngCore + CryptoRng>( self, rng: R, sighash: [u8; 32], signing_keys: &[SpendAuthorizingKey], ) -> Result<Bundle<Authorized, V>, BuildError>
Applies signatures to this bundle, in order to authorize it.
This is a helper method that wraps Bundle::prepare, Bundle::sign, and
Bundle::finalize.
Sourceimpl<P: Debug, V> Bundle<InProgress<P, PartiallyAuthorized>, V>
impl<P: Debug, V> Bundle<InProgress<P, PartiallyAuthorized>, V>
Sourcepub fn sign<R: RngCore + CryptoRng>(
self,
rng: R,
ask: &SpendAuthorizingKey,
) -> Self
pub fn sign<R: RngCore + CryptoRng>( self, rng: R, ask: &SpendAuthorizingKey, ) -> Self
Signs this bundle with the given SpendAuthorizingKey.
This will apply signatures for all notes controlled by this spending key.
Sourcepub fn append_signatures(
self,
signatures: &[Signature<SpendAuth>],
) -> Result<Self, BuildError>
pub fn append_signatures( self, signatures: &[Signature<SpendAuth>], ) -> Result<Self, BuildError>
Appends externally computed Signatures.
Each signature will be applied to the one input for which it is valid. An error will be returned if the signature is not valid for any inputs, or if it is valid for more than one input.
Sourceimpl<V> Bundle<InProgress<Proof, PartiallyAuthorized>, V>
impl<V> Bundle<InProgress<Proof, PartiallyAuthorized>, V>
Sourcepub fn finalize(self) -> Result<Bundle<Authorized, V>, BuildError>
pub fn finalize(self) -> Result<Bundle<Authorized, V>, BuildError>
Finalizes this bundle, enabling it to be included in a transaction.
Returns an error if any signatures are missing.
Sourceimpl<T: Authorization, V> Bundle<T, V>
impl<T: Authorization, V> Bundle<T, V>
Sourcepub fn from_parts(
actions: NonEmpty<Action<T::SpendAuth>>,
flags: Flags,
value_balance: V,
anchor: Anchor,
authorization: T,
) -> Self
pub fn from_parts( actions: NonEmpty<Action<T::SpendAuth>>, flags: Flags, value_balance: V, anchor: Anchor, authorization: T, ) -> Self
Constructs a Bundle from its constituent parts.
Sourcepub fn actions(&self) -> &NonEmpty<Action<T::SpendAuth>>
pub fn actions(&self) -> &NonEmpty<Action<T::SpendAuth>>
Returns the list of actions that make up this bundle.
Sourcepub fn flags(&self) -> &Flags
pub fn flags(&self) -> &Flags
Returns the Orchard-specific transaction-level flags for this bundle.
Sourcepub fn value_balance(&self) -> &V
pub fn value_balance(&self) -> &V
Returns the net value moved into or out of the Orchard shielded pool.
This is the sum of Orchard spends minus the sum Orchard outputs.
Sourcepub fn anchor(&self) -> &Anchor
pub fn anchor(&self) -> &Anchor
Returns the root of the Orchard commitment tree that this bundle commits to.
Returns the authorization for this bundle.
In the case of a Bundle<Authorized>, this is the proof and binding signature.
Sourcepub fn try_map_value_balance<V0, E, F: FnOnce(V) -> Result<V0, E>>(
self,
f: F,
) -> Result<Bundle<T, V0>, E>
pub fn try_map_value_balance<V0, E, F: FnOnce(V) -> Result<V0, E>>( self, f: F, ) -> Result<Bundle<T, V0>, E>
Construct a new bundle by applying a transformation that might fail to the value balance.
Transitions this bundle from one authorization state to another.
Transitions this bundle from one authorization state to another.
Sourcepub fn decrypt_outputs_with_keys(
&self,
keys: &[IncomingViewingKey],
) -> Vec<(usize, IncomingViewingKey, Note, Address, [u8; 512])>
pub fn decrypt_outputs_with_keys( &self, keys: &[IncomingViewingKey], ) -> Vec<(usize, IncomingViewingKey, Note, Address, [u8; 512])>
Performs trial decryption of each action in the bundle with each of the specified incoming viewing keys, and returns a vector of each decrypted note plaintext contents along with the index of the action from which it was derived.
Sourcepub fn decrypt_output_with_key(
&self,
action_idx: usize,
key: &IncomingViewingKey,
) -> Option<(Note, Address, [u8; 512])>
pub fn decrypt_output_with_key( &self, action_idx: usize, key: &IncomingViewingKey, ) -> Option<(Note, Address, [u8; 512])>
Performs trial decryption of the action at action_idx in the bundle with the
specified incoming viewing key, and returns the decrypted note plaintext
contents if successful.
Sourcepub fn recover_outputs_with_ovks(
&self,
keys: &[OutgoingViewingKey],
) -> Vec<(usize, OutgoingViewingKey, Note, Address, [u8; 512])>
pub fn recover_outputs_with_ovks( &self, keys: &[OutgoingViewingKey], ) -> Vec<(usize, OutgoingViewingKey, Note, Address, [u8; 512])>
Performs trial decryption of each action in the bundle with each of the specified outgoing viewing keys, and returns a vector of each decrypted note plaintext contents along with the index of the action from which it was derived.
Sourcepub fn recover_output_with_ovk(
&self,
action_idx: usize,
key: &OutgoingViewingKey,
) -> Option<(Note, Address, [u8; 512])>
pub fn recover_output_with_ovk( &self, action_idx: usize, key: &OutgoingViewingKey, ) -> Option<(Note, Address, [u8; 512])>
Attempts to decrypt the action at the specified index with the specified outgoing viewing key, and returns the decrypted note plaintext contents if successful.
Sourceimpl<T: Authorization, V: Copy + Into<i64>> Bundle<T, V>
impl<T: Authorization, V: Copy + Into<i64>> Bundle<T, V>
Sourcepub fn commitment(&self) -> BundleCommitment
pub fn commitment(&self) -> BundleCommitment
Computes a commitment to the effects of this bundle, suitable for inclusion within a transaction ID.
Sourcepub fn binding_validating_key(&self) -> VerificationKey<Binding>
pub fn binding_validating_key(&self) -> VerificationKey<Binding>
Returns the transaction binding validating key for this bundle.
This can be used to validate the Authorized::binding_signature returned from
Bundle::authorization.
Sourceimpl<V> Bundle<Authorized, V>
impl<V> Bundle<Authorized, V>
Computes a commitment to the authorizing data within for this bundle.
This together with Bundle::commitment bind the entire bundle.
Sourcepub fn verify_proof(&self, vk: &VerifyingKey) -> Result<(), Error>
Available on crate feature circuit only.
pub fn verify_proof(&self, vk: &VerifyingKey) -> Result<(), Error>
circuit only.Verifies the proof for this bundle.
Sourceimpl<V> Bundle<Unbound, V>
impl<V> Bundle<Unbound, V>
Sourcepub fn apply_binding_signature<R: RngCore + CryptoRng>(
self,
sighash: [u8; 32],
rng: R,
) -> Option<Bundle<Authorized, V>>
pub fn apply_binding_signature<R: RngCore + CryptoRng>( self, sighash: [u8; 32], rng: R, ) -> Option<Bundle<Authorized, V>>
Verifies the given sighash with every spend_auth_sig, and then binds the bundle.
Returns None if the given sighash does not validate against every spend_auth_sig.